import json
import logging

data_path = None
dic_data = None
modify_data = dict()

# set the path of test data and update the dictionary
def set_data_path(file_path):
    global data_path
    data_path = file_path
    global dic_data
    dic_data = get_json_object(data_path)
    if type(modify_data) == dict and len(modify_data.items()):
        modify_main_dict_value_param()
def modify_parameter(param):
    global modify_data
    modify_data = param

def get_json_object(file_path):
    with open(file_path, 'r') as f:
        distros_dict = json.load(f)
    return distros_dict

def get_json_dict(file_path):
    logging.info(file_path)
    with open(file_path, 'r') as f:
        distros_dict = json.load(f)
    return distros_dict

def modify_main_dict_value_param():
    for modify_key, modify_value in modify_data.items():
        key_found = search_dict_key(dic_data, modify_key)
        if key_found:
            dic_data[modify_key] = modify_value


# Search a given key inside dictionary recursively
def search_dict_key(target_dict, search_key):
    for key, value in target_dict.items():
        if key == search_key and type(value) == dict:
            return target_dict[key]
        elif key == search_key:
            return True
        elif type(value) == dict:
            key_found = search_dict_key(target_dict[key], search_key)
            if key_found:
                return key_found
    return None

def parse_json_recursively(json_object, target_key):
    my_dict = {}
    if type(json_object) is dict and json_object:
        for key in list(json_object.keys()):
            if key == target_key:
                my_dict[key] = json_object[key]
            parse_json_recursively(json_object[key], target_key)
    elif type(json_object) is list and json_object:
        for item in json_object:
            parse_json_recursively(item, target_key)

    return my_dict


def fetch_data(target_key, nested_dictionary):
    if type(nested_dictionary) is list and nested_dictionary:
        for item in nested_dictionary:
            if type(item) is dict and item:
                for x in item:
                    if x == target_key:
                        print(item[x])
                        return item[x]
            else:
                return nested_dictionary[target_key]
    else:
        for key, dic_value in nested_dictionary.items():
            if type(dic_value) is dict and dic_value:
                if key == target_key:
                    return dic_value
            if type(dic_value) is dict and dic_value:
                for x in dic_value:
                    if x == target_key:
                        return dic_value[x]
            elif type(dic_value) is str and dic_value:
                for key_string, value_string in nested_dictionary.items():
                    if key_string == target_key:
                        return value_string
                return None
        return dic_value


def get_data(target_key, nested_dictionary=None):
    global dic_data
    if dic_data is None and nested_dictionary is None:
        dic_data = get_json_object(data_path)
    if nested_dictionary:
        test_data = fetch_data(target_key, nested_dictionary)
        return test_data
    if dic_data:
        test_data = fetch_data(target_key, dic_data)
        return test_data


def get_value(json_object, exp_key, similar=False):
    for key, data in json_object.items():
        if (key.lower() == exp_key.lower() or (exp_key.lower() in key.lower() and similar)) and type(
                data) == dict and data.get('value'):
            # Skip the value and return None if flag is true
            if data.get('skip_value'):
                return None
            return data.get('value')
        # Handling for Empty json objects in data file
        elif type(data) == dict and len(data):
            aux_value = get_value(data, exp_key)
            if aux_value is not None:
                return aux_value
    return None


def get_data_object(target_key, nested_dictionary=None):
    if nested_dictionary is None:
        nested_dictionary = parse_json_recursively(dic_data, target_key)
        for key, data in nested_dictionary.items():
            if type(data) is not dict and data:
                return data
            else:
                return nested_dictionary
    elif nested_dictionary is not None:
        test_data = fetch_data(target_key, nested_dictionary)
        return test_data



import platform
from configparser import ConfigParser
import os

root_folder = os.getcwd()
current_os = platform.system()

config = ConfigParser(comment_prefixes='/', allow_no_value=True)
if current_os == "Linux":
    config.read('config.ini')
else:
    config.read(os.path.join(root_folder, "config.ini"))


def get_config(key):
    return config['Configuration'].get(key)





import json
import logging
import pprint
from functools import wraps
from json import JSONDecodeError
logger = logging.getLogger("api")


def logging(message):
    """
    Request Logging
    :return: response
    """

    def wrapper(function):
        @wraps(function)
        def inner(*args, **kwargs):
            logger.info(message)
            res = function(*args, **kwargs)
            method = res.request.method
            url = res.request.url
            body = res.request.body
            logger.info(res)
            status = res.status_code
            body_sep = " "
            log_request = f"Request method: {method}, url: {url}"
            if body is not None:
                try:
                    json_body = json.loads(res.text)
                    if len(body) > 20:
                        body_sep = "\n"
                    log_request += (
                        f", body:{body_sep}{json_body or pprint.pformat(body)}"
                    )
                except AttributeError:
                    log_request += f", body:{body}"
            log_response = f"Response method: {method}, url: {url}, status: {status}"
            try:
                body = res.json()
                if len(res.content) > 20:
                    body_sep = "\n"
                    bd = json.dumps(body, indent=4, ensure_ascii=False)
                    log_response += f", body:{body_sep}{bd}"
                else:
                    log_response += f", body:{json.dumps(body)}"
                logger.info(log_response)
            except JSONDecodeError:
                if len(res.text) > 120:
                    log_response += f", body: {res.text[:120]}..."
                else:
                    log_response += f", body: {res.text}"
                logger.info(log_response)
            return res

        return inner

    return wrapper



from  setuptools import setup, find_packages

ignore_init_rgx = "[!__init__]"

setup(
    name='automation-common-test',
    version='2.0.5',
    author='Chitranjan Kumar',
    author_email='chitranjan.kumar@kyndryl.com',
    description='This is the common automation framework',
    license='Kyndryl',
    include_package_data=True,
    packages=find_packages(),
)


import logging
import os
from cryptography.fernet import Fernet
secret_name = 'MCMP_UI_AUTO_SECRET'


def generate_key():
    """
    Generates a key
    """
    return Fernet.generate_key()


def encrypt_password(password, secret=os.getenv(secret_name)):
    """
    Encrypts a password
    """
    encoded_password = password.encode()
    f = Fernet(secret)
    try:
        return f.encrypt(encoded_password)
    except:
        return 'Secret key is invalid'


def decrypt_password(encrypted_password, secret=os.getenv(secret_name)):
    """
    Decrypts an encrypted password
    """
    encoding = 'utf-8'
    if os.environ.get("encryption_key"):
        f = Fernet(os.environ.get("encryption_key"))
    else:
        f = Fernet(secret)
    encrypted_password = bytes(encrypted_password, encoding)
    try:
        decrypted_password = f.decrypt(encrypted_password)
        return str(decrypted_password, encoding)
    except:
        return 'Secret or Token is invalid'


def main(args):
    if args.decrypt:
        text = decrypt_password(args.text, args.secret)
    else:
        text = encrypt_password(args.text, args.secret)
    return text


if __name__ == "__main__":
    import argparse

    parser = argparse.ArgumentParser()
    parser.add_argument('text', help='The password or token to be encrypted or decrypted')
    parser.add_argument('-d', '--decrypt', action='store_true', help='To decrypt')
    parser.add_argument('--secret', default=os.getenv(secret_name), help='Secret key to be used for encryption')

    print(main(parser.parse_args()))
